@@ -23,6 +23,8 @@
 from __future__ import unicode_literals
 from __future__ import absolute_import
 
+import uuid
+
 __author__ = "czerwin@scalyr.com"
 
 import platform
@@ -68,6 +70,46 @@ def _set_last_timestamp(val):
     __last_time_stamp__ = val
 
 
+class NewScalyrClientSession(object):
+    def __init__(self, configuration):
+        if configuration.use_new_ingestion:
+            from scalyr_ingestion_client.session import (  # pylint: disable=import-error
+                Session,
+            )
+            from scalyr_ingestion_client.client import (  # pylint: disable=import-error
+                ControlPlaneAPIClient,
+                DataPlaneAPIClient,
+            )
+
+            self._session = Session(uuid=str(uuid.uuid4()))
+
+            self._control_plane_client = ControlPlaneAPIClient(
+                service_address=configuration.new_ingestion_bootstrap_address.split(
+                    ":"
+                ),
+                api_token=str(configuration.api_key),
+                cert_path=str(configuration.ca_cert_path),
+                use_tls=configuration.new_ingestion_use_tls,
+            )
+            manager_address = self._control_plane_client.send_client_hello()
+
+            self._data_plane_client = DataPlaneAPIClient(
+                api_token=str(configuration.api_key),
+                service_address=(manager_address.ip_address, manager_address.port),
+                cert_path=str(configuration.ca_cert_path),
+                use_tls=configuration.new_ingestion_use_tls,
+            )
+
+    def send_events(self, log_stream, events, sequence_range_start, sequence_range_end):
+        self._data_plane_client.send_events(
+            session=self._session,
+            log_stream=log_stream,
+            events=events,
+            sequence_range_start=sequence_range_start,
+            sequence_range_end=sequence_range_end,
+        )
+
+
 class ScalyrClientSession(object):
     """Encapsulates the connection between the agent and the Scalyr servers.
 
